@@ -22,6 +22,8 @@ func getAllKeysSharedNetwork4() string {
 		"authoritative": false,
 		"boot-file-name": "/dev/null",
 		"client-class": "foobar",
+		"client-classes": [ "early" ],
+		"evaluate-additional-classes": [ "early" ],
 		"ddns-generated-prefix": "myhost",
 		"ddns-override-client-update": true,
 		"ddns-override-no-update": true,
@@ -81,6 +83,7 @@ func getAllKeysSharedNetwork6() string {
 		"allocator": "random",
 		"pd-allocator": "iterative",
 		"client-class": "foobar",
+		"client-classes": [ "early" ],
 		"ddns-generated-prefix": "myhost",
 		"ddns-override-client-update": true,
 		"ddns-override-no-update": true,
@@ -89,6 +92,7 @@ func getAllKeysSharedNetwork6() string {
 		"ddns-send-updates": true,
 		"ddns-update-on-renew": true,
 		"ddns-use-conflict-resolution": true,
+		"evaluate-additional-classes": [ "early" ],
 		"hostname-char-replacement": "x",
 		"hostname-char-set": "[^A-Za-z0-9.-]",
 		"interface": "eth0",
@@ -144,6 +148,8 @@ func TestDecodeAllKeysSharedNetwork4(t *testing.T) {
 	require.Equal(t, "random", *params.Allocator)
 	require.Equal(t, "/dev/null", *params.BootFileName)
 	require.Equal(t, "foobar", *params.ClientClass)
+	require.Len(t, params.ClientClasses, 1)
+	require.Equal(t, "early", params.ClientClasses[0])
 	require.Equal(t, "myhost", *params.DDNSGeneratedPrefix)
 	require.True(t, *params.DDNSOverrideClientUpdate)
 	require.True(t, *params.DDNSOverrideNoUpdate)
@@ -152,6 +158,8 @@ func TestDecodeAllKeysSharedNetwork4(t *testing.T) {
 	require.True(t, *params.DDNSSendUpdates)
 	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
+	require.Len(t, params.EvaluateAdditionalClasses, 1)
+	require.Equal(t, "early", params.EvaluateAdditionalClasses[0])
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
 	require.Equal(t, "eth0", *params.Interface)
@@ -195,6 +203,8 @@ func TestDecodeAllKeysSharedNetwork6(t *testing.T) {
 	require.Equal(t, "random", *params.Allocator)
 	require.Equal(t, "iterative", *params.PDAllocator)
 	require.Equal(t, "foobar", *params.ClientClass)
+	require.Len(t, params.ClientClasses, 1)
+	require.Equal(t, "early", params.ClientClasses[0])
 	require.Equal(t, "myhost", *params.DDNSGeneratedPrefix)
 	require.True(t, *params.DDNSOverrideClientUpdate)
 	require.True(t, *params.DDNSOverrideNoUpdate)
@@ -203,6 +213,8 @@ func TestDecodeAllKeysSharedNetwork6(t *testing.T) {
 	require.True(t, *params.DDNSSendUpdates)
 	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
+	require.Len(t, params.EvaluateAdditionalClasses, 1)
+	require.Equal(t, "early", params.EvaluateAdditionalClasses[0])
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
 	require.Equal(t, "eth0", *params.Interface)
@@ -248,6 +260,8 @@ func TestGetParametersSharedNetwork4(t *testing.T) {
 	require.Equal(t, "random", *params.Allocator)
 	require.Equal(t, "/dev/null", *params.BootFileName)
 	require.Equal(t, "foobar", *params.ClientClass)
+	require.Len(t, params.ClientClasses, 1)
+	require.Equal(t, "early", params.ClientClasses[0])
 	require.Equal(t, "myhost", *params.DDNSGeneratedPrefix)
 	require.True(t, *params.DDNSOverrideClientUpdate)
 	require.True(t, *params.DDNSOverrideNoUpdate)
@@ -256,6 +270,8 @@ func TestGetParametersSharedNetwork4(t *testing.T) {
 	require.True(t, *params.DDNSSendUpdates)
 	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
+	require.Len(t, params.EvaluateAdditionalClasses, 1)
+	require.Equal(t, "early", params.EvaluateAdditionalClasses[0])
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
 	require.Equal(t, "eth0", *params.Interface)
@@ -302,6 +318,8 @@ func TestGetParametersSharedNetwork6(t *testing.T) {
 	require.True(t, *params.DDNSSendUpdates)
 	require.True(t, *params.DDNSUpdateOnRenew)
 	require.True(t, *params.DDNSUseConflictResolution)
+	require.Len(t, params.EvaluateAdditionalClasses, 1)
+	require.Equal(t, "early", params.EvaluateAdditionalClasses[0])
 	require.Equal(t, "x", *params.HostnameCharReplacement)
 	require.Equal(t, "[^A-Za-z0-9.-]", *params.HostnameCharSet)
 	require.Equal(t, "eth0", *params.Interface)
@@ -344,8 +362,10 @@ func TestCreateSharedNetwork4(t *testing.T) {
 			CacheThreshold: ptr[float32](0.25),
 		},
 		ClientClassParameters: keaconfig.ClientClassParameters{
-			ClientClass:          ptr("myclass"),
-			RequireClientClasses: []string{"foo"},
+			ClientClass:               ptr("myclass"),
+			ClientClasses:             []string{"bar"},
+			EvaluateAdditionalClasses: []string{"bar"},
+			RequireClientClasses:      []string{"foo"},
 		},
 		DDNSParameters: keaconfig.DDNSParameters{
 			DDNSGeneratedPrefix:       ptr("example.com"),
@@ -434,6 +454,8 @@ func TestCreateSharedNetwork4(t *testing.T) {
 	require.EqualValues(t, 0.25, *network4.CacheThreshold)
 	require.True(t, *network4.CalculateTeeTimes)
 	require.Equal(t, "myclass", *network4.ClientClass)
+	require.Len(t, network4.ClientClasses, 1)
+	require.Equal(t, "bar", network4.ClientClasses[0])
 	require.Equal(t, "example.com", *network4.DDNSGeneratedPrefix)
 	require.True(t, *network4.DDNSOverrideClientUpdate)
 	require.True(t, *network4.DDNSOverrideNoUpdate)
@@ -441,6 +463,8 @@ func TestCreateSharedNetwork4(t *testing.T) {
 	require.Equal(t, "never", *network4.DDNSReplaceClientName)
 	require.True(t, *network4.DDNSSendUpdates)
 	require.True(t, *network4.DDNSUseConflictResolution)
+	require.Len(t, network4.EvaluateAdditionalClasses, 1)
+	require.Equal(t, "bar", network4.EvaluateAdditionalClasses[0])
 	require.Equal(t, "xyz", *network4.HostnameCharReplacement)
 	require.Equal(t, "[A-z]", *network4.HostnameCharSet)
 	require.Equal(t, "etx0", *network4.Interface)
@@ -489,8 +513,10 @@ func TestCreateSharedNetwork6(t *testing.T) {
 			CacheThreshold: ptr[float32](0.25),
 		},
 		ClientClassParameters: keaconfig.ClientClassParameters{
-			ClientClass:          ptr("myclass"),
-			RequireClientClasses: []string{"foo"},
+			ClientClass:               ptr("myclass"),
+			ClientClasses:             []string{"bar"},
+			EvaluateAdditionalClasses: []string{"bar"},
+			RequireClientClasses:      []string{"foo"},
 		},
 		DDNSParameters: keaconfig.DDNSParameters{
 			DDNSGeneratedPrefix:       ptr("example.com"),
@@ -581,6 +607,8 @@ func TestCreateSharedNetwork6(t *testing.T) {
 	require.EqualValues(t, 0.25, *network6.CacheThreshold)
 	require.True(t, *network6.CalculateTeeTimes)
 	require.Equal(t, "myclass", *network6.ClientClass)
+	require.Len(t, network6.ClientClasses, 1)
+	require.Equal(t, "bar", network6.ClientClasses[0])
 	require.Equal(t, "example.com", *network6.DDNSGeneratedPrefix)
 	require.True(t, *network6.DDNSOverrideClientUpdate)
 	require.True(t, *network6.DDNSOverrideNoUpdate)
@@ -588,6 +616,8 @@ func TestCreateSharedNetwork6(t *testing.T) {
 	require.Equal(t, "never", *network6.DDNSReplaceClientName)
 	require.True(t, *network6.DDNSSendUpdates)
 	require.True(t, *network6.DDNSUseConflictResolution)
+	require.Len(t, network6.EvaluateAdditionalClasses, 1)
+	require.Equal(t, "bar", network6.EvaluateAdditionalClasses[0])
 	require.Equal(t, "xyz", *network6.HostnameCharReplacement)
 	require.Equal(t, "[A-z]", *network6.HostnameCharSet)
 	require.Equal(t, "etx0", *network6.Interface)
