@@ -15,7 +15,7 @@ import (
 )
 
 const (
-	// A limit for returned hosts number in the the reservation-get-page command.
+	// A limit for returned hosts number in the reservation-get-page command.
 	defaultHostCmdsPageLimit int64 = 1000
 )
 
@@ -368,21 +368,8 @@ func (iterator *hostIterator) sendReservationGetPage() ([]keaconfig.Reservation,
 			}
 		}
 	}
-	// The subnet-id and limit are mandatory.
-	arguments := map[string]interface{}{
-		"subnet-id": subnetID,
-		"limit":     iterator.limit,
-	}
-	// The from and source-index values are not present in a first call to
-	// fetch the hosts for a given subnet.
-	if iterator.from > 0 {
-		arguments["from"] = iterator.from
-	}
-	if iterator.sourceIndex > 0 {
-		arguments["source-index"] = iterator.sourceIndex
-	}
 	// Prepare the command.
-	command := keactrl.NewCommand("reservation-get-page", daemons, arguments)
+	command := keactrl.NewCommandReservationGetPage(subnetID, iterator.sourceIndex, iterator.from, iterator.limit, daemons...)
 	commands := []keactrl.SerializableCommand{command}
 	response := make([]ReservationGetPageResponse, 1)
 	ctx := context.Background()
