@@ -61,11 +61,13 @@ func TestNewManager(t *testing.T) {
 
 	agents := &agentcommtest.FakeAgents{}
 	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	daemonLocker := config.NewDaemonLocker()
 
 	manager := NewManager(&appstest.ManagerAccessorsWrapper{
-		DB:        db,
-		Agents:    agents,
-		DefLookup: lookup,
+		DB:           db,
+		Agents:       agents,
+		DefLookup:    lookup,
+		DaemonLocker: daemonLocker,
 	})
 	require.NotNil(t, manager)
 	require.NotNil(t, manager.GetKeaModule())
@@ -76,6 +78,7 @@ func TestNewManager(t *testing.T) {
 	require.Equal(t, db, impl.GetDB())
 	require.Equal(t, agents, impl.GetConnectedAgents())
 	require.Equal(t, lookup, impl.GetDHCPOptionDefinitionLookup())
+	require.Equal(t, daemonLocker, impl.GetDaemonLocker())
 }
 
 // Test creating new context with context ID and user ID.
@@ -93,9 +96,9 @@ func TestCreateContext(t *testing.T) {
 		require.NotNil(t, ctx)
 
 		// Make sure that the context ID exists.
-		ctxid, ok := config.GetValueAsInt64(ctx, config.ContextIDKey)
+		ctxID, ok := config.GetValueAsInt64(ctx, config.ContextIDKey)
 		require.True(t, ok)
-		ids[ctxid] = true
+		ids[ctxID] = true
 
 		// Make sure that the user ID exists.
 		userid, ok := config.GetValueAsInt64(ctx, config.UserContextKey)
@@ -183,7 +186,9 @@ func TestRememberRecoverContext(t *testing.T) {
 
 // Test the case when a timeout occurs during config update.
 func TestContextTimeout(t *testing.T) {
-	manager := NewManager(&appstest.ManagerAccessorsWrapper{})
+	manager := NewManager(&appstest.ManagerAccessorsWrapper{
+		DaemonLocker: config.NewDaemonLocker(),
+	})
 	require.NotNil(t, manager)
 
 	ctx, err := manager.CreateContext(int64(123))
@@ -230,7 +235,9 @@ func TestContextTimeout(t *testing.T) {
 // Test that calling Done() function results in removing the context and
 // unlocking the configuration.
 func TestDone(t *testing.T) {
-	manager := NewManager(&appstest.ManagerAccessorsWrapper{})
+	manager := NewManager(&appstest.ManagerAccessorsWrapper{
+		DaemonLocker: config.NewDaemonLocker(),
+	})
 	require.NotNil(t, manager)
 
 	ctx, err := manager.CreateContext(int64(123))
@@ -336,7 +343,9 @@ func TestRecoverContextMismatch(t *testing.T) {
 // Test that daemon configurations can be locked for updates and then
 // unlocked allowing for locking again.
 func TestLockUnlock(t *testing.T) {
-	manager := NewManager(&appstest.ManagerAccessorsWrapper{})
+	manager := NewManager(&appstest.ManagerAccessorsWrapper{
+		DaemonLocker: config.NewDaemonLocker(),
+	})
 	require.NotNil(t, manager)
 
 	// Create context and lock daemons 1, 2, 3.
@@ -367,6 +376,35 @@ func TestLockUnlock(t *testing.T) {
 	require.NoError(t, err)
 }
 
+// Test that the context passed to the Unlock method must contain the lock key.
+// Otherwise, no daemons are unlocked.
+func TestUnlockForMissingKey(t *testing.T) {
+	// Arrange
+	locker := config.NewDaemonLocker()
+	manager := NewManager(&appstest.ManagerAccessorsWrapper{
+		DaemonLocker: locker,
+	})
+	require.NotNil(t, manager)
+
+	lockCtx, _ := manager.CreateContext(123)
+	lockCtx, _ = manager.Lock(lockCtx, 1, 2, 3)
+
+	// Context with no lock key.
+	unlockCtx := context.WithValue(
+		context.Background(),
+		config.DaemonsContextKey,
+		lockCtx.Value(config.DaemonsContextKey),
+	)
+
+	// Act
+	manager.Unlock(unlockCtx)
+
+	// Assert
+	for _, daemonID := range []int64{1, 2, 3} {
+		require.True(t, locker.IsLocked(daemonID))
+	}
+}
+
 // Test that the commit call is routed to the Kea module when the
 // transaction target is dbmodel.AppTypeKea.
 func TestCommitKeaModule(t *testing.T) {
