@@ -5,11 +5,12 @@ import (
 	"crypto/ecdsa"
 	"crypto/rand"
 	"crypto/x509"
-	"encoding/pem"
+	"fmt"
 	"io"
 	"math/big"
 	"net"
 	"os"
+	"strings"
 	"time"
 
 	"github.com/go-pg/pg/v10"
@@ -49,56 +50,116 @@ func GenerateServerToken(db *pg.DB) ([]byte, error) {
 	return serverToken, nil
 }
 
+// This function checks if the root CA must be invalidated and generated again
+// because it doesn't fulfill the current Stork version requirements.
+func verifyRootCACustomRequirements(rootCert *x509.Certificate) error {
+	var issues []string
+
+	// Key usage.
+	expectedKeyUsage := x509.KeyUsageCertSign | x509.KeyUsageDigitalSignature
+	if rootCert.KeyUsage != expectedKeyUsage {
+		issues = append(issues, "invalid key usage")
+	}
+
+	// Extended key usage.
+	mandatoryExtKeyUsage := map[x509.ExtKeyUsage]bool{
+		x509.ExtKeyUsageClientAuth: false,
+		x509.ExtKeyUsageServerAuth: false,
+	}
+
+	extKeyUsageNames := map[x509.ExtKeyUsage]string{
+		x509.ExtKeyUsageClientAuth: "Client Authentication",
+		x509.ExtKeyUsageServerAuth: "Server Authentication",
+	}
+
+	for _, extKeyUsage := range rootCert.ExtKeyUsage {
+		if _, ok := mandatoryExtKeyUsage[extKeyUsage]; ok {
+			mandatoryExtKeyUsage[extKeyUsage] = true
+		}
+	}
+
+	for extKeyUsage, isPresent := range mandatoryExtKeyUsage {
+		if !isPresent {
+			issues = append(issues, fmt.Sprintf(
+				"missing mandatory extended key usage: %s",
+				extKeyUsageNames[extKeyUsage],
+			))
+		}
+	}
+
+	if len(issues) == 0 {
+		return nil
+	}
+
+	return errors.New(strings.Join(issues, "; "))
+}
+
 // Check if a root CA key and a root CA certs are present in db. If not generate them
 // and store in database.
 func setupRootKeyAndCert(db *pg.DB) (*ecdsa.PrivateKey, *x509.Certificate, []byte, error) {
 	// check root key and root cert, if missing then generate them
 	rootKeyPEM, err := dbmodel.GetSecret(db, dbmodel.SecretCAKey)
 	if err != nil {
-		return nil, nil, nil, errors.Wrapf(err, "problem getting CA key from database")
+		return nil, nil, nil, errors.WithMessage(err, "problem getting CA key from database")
 	}
 	rootCertPEM, err := dbmodel.GetSecret(db, dbmodel.SecretCACert)
 	if err != nil {
-		return nil, nil, nil, errors.Wrapf(err, "problem getting CA cert from database")
+		return nil, nil, nil, errors.WithMessage(err, "problem getting CA cert from database")
 	}
 
 	var rootKey *ecdsa.PrivateKey
 	var rootCert *x509.Certificate
 
-	// no root key or no root cert so generate them
-	if rootKeyPEM == nil || rootCertPEM == nil {
+	if rootKeyPEM != nil && rootCertPEM != nil {
+		// key and cert present in db so just check them
+		rootKey, err = pki.ParsePrivateKey(rootKeyPEM)
+		if err != nil {
+			return nil, nil, nil, errors.WithMessage(err, "cannot parse root CA key")
+		}
+
+		rootCert, err = pki.ParseCert(rootCertPEM)
+		if err != nil {
+			return nil, nil, nil, errors.WithMessage(err, "cannot parse root CA cert")
+		}
+
+		if err := verifyRootCACustomRequirements(rootCert); err == nil {
+			log.Info("Root CA key and cert OK")
+		} else if ok := pki.IsSelfSigned(rootCert) && pki.IsInternalCert(rootCert); ok {
+			log.WithError(err).
+				Warn("Root CA cert must be regenerated")
+			rootKey = nil
+			rootCert = nil
+		} else {
+			msg := "Existing Stork Root CA certificates apparently were not " +
+				"generated by Stork but created externally and imported to " +
+				"the Stork database. These certificates no longer meet the " +
+				"security standards required by Stork and have to be " +
+				"regenerated and imported again. Please refer to the Stork " +
+				"documentation and ISC Knowledge Base on how to generate " +
+				"and import the new certificates."
+			return nil, nil, nil, errors.WithMessage(err, msg)
+		}
+	}
+
+	if rootKey == nil || rootCert == nil {
+		// No root key or no root cert or it is out-of-date so generate them.
 		certSerialNumber, err := dbmodel.GetNewCertSerialNumber(db)
 		if err != nil {
-			return nil, nil, nil, errors.Wrapf(err, "cannot get new cert S/N")
+			return nil, nil, nil, errors.WithMessage(err, "cannot get new cert S/N")
 		}
 		rootKey, rootKeyPEM, rootCert, rootCertPEM, err = pki.GenCAKeyCert(certSerialNumber)
 		if err != nil {
-			return nil, nil, nil, errors.Wrapf(err, "cannot generate root CA cert")
+			return nil, nil, nil, errors.WithMessage(err, "cannot generate root CA cert")
 		}
 		err = dbmodel.SetSecret(db, dbmodel.SecretCAKey, rootKeyPEM)
 		if err != nil {
-			return nil, nil, nil, errors.Wrapf(err, "cannot store root CA key in database")
+			return nil, nil, nil, errors.WithMessage(err, "cannot store root CA key in database")
 		}
 		err = dbmodel.SetSecret(db, dbmodel.SecretCACert, rootCertPEM)
 		if err != nil {
-			return nil, nil, nil, errors.Wrapf(err, "cannot store root CA key in database")
+			return nil, nil, nil, errors.WithMessage(err, "cannot store root CA key in database")
 		}
 		log.Printf("Generated root CA key and cert")
-	} else {
-		// key and cert present in db so just check them
-		rootKeyPEMBlock, _ := pem.Decode(rootKeyPEM)
-		rootKeyIf, err := x509.ParsePKCS8PrivateKey(rootKeyPEMBlock.Bytes)
-		if err != nil {
-			return nil, nil, nil, errors.Wrapf(err, "cannot parse root CA key")
-		}
-		rootKey = rootKeyIf.(*ecdsa.PrivateKey)
-
-		rootCertPEMBlock, _ := pem.Decode(rootCertPEM)
-		rootCert, err = x509.ParseCertificate(rootCertPEMBlock.Bytes)
-		if err != nil {
-			return nil, nil, nil, errors.Wrapf(err, "cannot parse root CA cert")
-		}
-		log.Printf("Root CA key and cert OK")
 	}
 
 	return rootKey, rootCert, rootCertPEM, nil
@@ -110,14 +171,59 @@ func setupServerKeyAndCert(db *pg.DB, rootKey *ecdsa.PrivateKey, rootCert *x509.
 	// check server cert, if missing then generate it
 	serverKeyPEM, err := dbmodel.GetSecret(db, dbmodel.SecretServerKey)
 	if err != nil {
-		return nil, nil, errors.Wrapf(err, "cannot get server key from database")
+		return nil, nil, errors.WithMessage(err, "cannot get server key from database")
 	}
 	serverCertPEM, err := dbmodel.GetSecret(db, dbmodel.SecretServerCert)
 	if err != nil {
-		return nil, nil, errors.Wrapf(err, "cannot get server cert from database")
+		return nil, nil, errors.WithMessage(err, "cannot get server cert from database")
 	}
 
 	// no server key or no server cert so generate
+	if serverKeyPEM != nil && serverCertPEM != nil {
+		// key and cert present in db so just check them
+		_, err := pki.ParsePrivateKey(serverKeyPEM)
+		if err != nil {
+			return nil, nil, errors.WithMessage(err, "cannot parse server key")
+		}
+
+		serverCert, err := pki.ParseCert(serverCertPEM)
+		if err != nil {
+			return nil, nil, errors.WithMessage(err, "cannot parse server cert")
+		}
+
+		// Check if the server cert is valid for the current root CA cert.
+		rootCAPool := x509.NewCertPool()
+		rootCAPool.AddCert(rootCert)
+
+		opts := x509.VerifyOptions{
+			Roots: rootCAPool,
+			KeyUsages: []x509.ExtKeyUsage{
+				// The Stork server is a client of the GRPC connection.
+				x509.ExtKeyUsageClientAuth,
+			},
+		}
+
+		if _, err = serverCert.Verify(opts); err == nil {
+			log.Printf("Server key and cert OK")
+		} else if pki.IsInternalCert(serverCert) && pki.IsInternalCert(rootCert) {
+			log.WithError(err).
+				Warn("Server cert is not valid for current root CA cert; it " +
+					"must be regenerated")
+			serverKeyPEM = nil
+			serverCertPEM = nil
+		} else {
+			msg := "Existing Stork server certificates apparently were not " +
+				"generated by Stork but created externally and imported to " +
+				"the Stork database. These certificates no longer meet the " +
+				"security standards required by Stork and have to be " +
+				"regenerated and imported again. Please refer to the Stork " +
+				"documentation and ISC Knowledge Base on how to generate " +
+				"and import the new certificates."
+			log.WithError(err).Error(msg)
+			return nil, nil, errors.WithMessage(err, msg)
+		}
+	}
+
 	if serverKeyPEM == nil || serverCertPEM == nil {
 		// get list of all host IP addresses that will be put to server cert
 		addrs, err := net.InterfaceAddrs()
@@ -149,35 +255,21 @@ func setupServerKeyAndCert(db *pg.DB, rootKey *ecdsa.PrivateKey, rootCert *x509.
 
 		certSerialNumber, err := dbmodel.GetNewCertSerialNumber(db)
 		if err != nil {
-			return nil, nil, errors.Wrapf(err, "cannot get new cert S/N")
+			return nil, nil, errors.WithMessage(err, "cannot get new cert S/N")
 		}
-		serverCertPEM, serverKeyPEM, err = pki.GenKeyCert("server", srvNames, srvIPs, certSerialNumber, rootCert, rootKey)
+		serverCertPEM, serverKeyPEM, err = pki.GenKeyCert("server", srvNames, srvIPs, certSerialNumber, rootCert, rootKey, x509.ExtKeyUsageClientAuth)
 		if err != nil {
-			return nil, nil, errors.Wrapf(err, "cannot generate key and cert for server")
+			return nil, nil, errors.WithMessage(err, "cannot generate key and cert for server")
 		}
 		err = dbmodel.SetSecret(db, dbmodel.SecretServerKey, serverKeyPEM)
 		if err != nil {
-			return nil, nil, errors.Wrapf(err, "cannot store server key in database")
+			return nil, nil, errors.WithMessage(err, "cannot store server key in database")
 		}
 		err = dbmodel.SetSecret(db, dbmodel.SecretServerCert, serverCertPEM)
 		if err != nil {
-			return nil, nil, errors.Wrapf(err, "cannot store server cert in database")
+			return nil, nil, errors.WithMessage(err, "cannot store server cert in database")
 		}
 		log.Printf("Generated server key and cert")
-	} else {
-		// key and cert present in db so just check them
-		serverKeyPEMBlock, _ := pem.Decode(serverKeyPEM)
-		_, err := x509.ParsePKCS8PrivateKey(serverKeyPEMBlock.Bytes)
-		if err != nil {
-			return nil, nil, errors.Wrapf(err, "cannot parse server key")
-		}
-
-		serverCertPEMBlock, _ := pem.Decode(serverCertPEM)
-		_, err = x509.ParseCertificate(serverCertPEMBlock.Bytes)
-		if err != nil {
-			return nil, nil, errors.Wrapf(err, "cannot parse server cert")
-		}
-		log.Printf("Server key and cert OK")
 	}
 
 	return serverKeyPEM, serverCertPEM, nil
@@ -205,12 +297,12 @@ func SetupServerCerts(db *pg.DB) ([]byte, []byte, []byte, error) {
 	// check server access token; if missing generate it
 	serverToken, err := dbmodel.GetSecret(db, dbmodel.SecretServerToken)
 	if err != nil {
-		return nil, nil, nil, errors.Wrapf(err, "cannot get server token from database")
+		return nil, nil, nil, errors.WithMessage(err, "cannot get server token from database")
 	}
 	if serverToken == nil {
 		_, err = GenerateServerToken(db)
 		if err != nil {
-			return nil, nil, nil, errors.Wrapf(err, "cannot generate server token")
+			return nil, nil, nil, errors.WithMessage(err, "cannot generate server token")
 		}
 	}
 
@@ -237,7 +329,7 @@ func ExportSecret(db *pg.DB, object string, filename string) error {
 
 	content, err := dbmodel.GetSecret(db, object)
 	if err != nil {
-		return errors.Wrapf(err, "problem getting '%s' from database", objDisplayName)
+		return errors.WithMessagef(err, "problem getting '%s' from database", objDisplayName)
 	}
 	if filename != "" {
 		err := os.WriteFile(filename, content, 0o600)
@@ -311,13 +403,13 @@ func ImportSecret(db *pg.DB, object string, filename string) error {
 	}
 
 	if err != nil {
-		return errors.Wrapf(err, "problem parsing the %s", objDisplayName)
+		return errors.WithMessagef(err, "problem parsing the %s", objDisplayName)
 	}
 
 	// The value looks reasonable. Let's set it in the DB
 	err = dbmodel.SetSecret(db, object, content)
 	if err != nil {
-		return errors.Wrapf(err, "problem setting '%s' in database", objDisplayName)
+		return errors.WithMessagef(err, "problem setting '%s' in database", objDisplayName)
 	}
 
 	return nil
