@@ -8,8 +8,8 @@ func init() {
 	migrations.MustRegisterTx(func(db migrations.DB) error {
 		_, err := db.Exec(`
             DELETE FROM service;
-            -- Existing foreign keys point to the app table, therefore they
-            -- have to be dropped.
+            -- Existing foreign keys point to the app table, so they
+            -- must be dropped.
             ALTER TABLE ha_service DROP CONSTRAINT IF EXISTS ha_service_primary_id;
             ALTER TABLE ha_service DROP CONSTRAINT IF EXISTS ha_service_secondary_id;
 
@@ -23,15 +23,15 @@ func init() {
                 ON UPDATE CASCADE
                 ON DELETE SET NULL;
 
-            -- The app_to_service provides M:N relation between services and apps.
-            -- We want to modify this relation to be between apps and daemons.
+            -- The app_to_service table provides M:N relation between services and apps.
+            -- This relation must be modified to be between apps and daemons.
             ALTER TABLE app_to_service DROP CONSTRAINT IF EXISTS app_to_service_app_id;
 
             -- The table and the app_id column must be renamed to reflect this new relationship.
             ALTER TABLE app_to_service RENAME TO daemon_to_service;
             ALTER TABLE daemon_to_service RENAME COLUMN app_id TO daemon_id;
 
-            -- Add the constraint back against the daemon table this time.
+            -- This adds the constraint back against the daemon table.
             ALTER TABLE daemon_to_service ADD CONSTRAINT daemon_to_service_daemon_id FOREIGN KEY (daemon_id)
                 REFERENCES daemon (id) MATCH SIMPLE
                 ON UPDATE NO ACTION
