@@ -1105,8 +1105,8 @@ func TestUpdateUtilization(t *testing.T) {
 	returnedSubnet2, err := GetSubnet(db, subnet.ID)
 	require.NoError(t, err)
 	require.NotNil(t, returnedSubnet2)
-	require.EqualValues(t, 10, returnedSubnet2.AddrUtilization)
-	require.EqualValues(t, 20, returnedSubnet2.PdUtilization)
+	require.EqualValues(t, 0.01, returnedSubnet2.AddrUtilization)
+	require.EqualValues(t, 0.02, returnedSubnet2.PdUtilization)
 	require.EqualValues(t, 1, returnedSubnet2.Stats["assigned-nas"])
 	require.EqualValues(t, 2, returnedSubnet2.Stats["assigned-pds"])
 	require.InDelta(t, time.Now().UTC().Unix(), returnedSubnet2.StatsCollectedAt.Unix(), 10.0)
