@@ -10,10 +10,9 @@ import (
 )
 
 type logSourceMockCall struct {
-	AgentAddress string
-	AgentPort    int64
-	Path         string
-	Offset       int64
+	machine dbmodel.MachineTag
+	Path    string
+	Offset  int64
 }
 
 type logSourceMock struct {
@@ -26,10 +25,9 @@ func newLogSourceMock(logs []string, err error) *logSourceMock {
 	return &logSourceMock{logs, err, []*logSourceMockCall{}}
 }
 
-func (s *logSourceMock) TailTextFile(ctx context.Context, agentAddress string, agentPort int64, path string, offset int64) ([]string, error) {
+func (s *logSourceMock) TailTextFile(ctx context.Context, machine dbmodel.MachineTag, path string, offset int64) ([]string, error) {
 	s.Calls = append(s.Calls, &logSourceMockCall{
-		agentAddress,
-		agentPort,
+		machine,
 		path,
 		offset,
 	})
@@ -69,10 +67,8 @@ func TestLogDumpExecute(t *testing.T) {
 	// Assert
 	require.NoError(t, err)
 	require.Len(t, logSource.Calls, 1) // Stdout output ignored.
-	require.EqualValues(t, &logSourceMockCall{
-		"foo",
-		42,
-		"/var/log/foo.log",
-		40000,
-	}, logSource.Calls[0])
+	require.Equal(t, "/var/log/foo.log", logSource.Calls[0].Path)
+	require.EqualValues(t, 40000, logSource.Calls[0].Offset)
+	require.Equal(t, "foo", logSource.Calls[0].machine.GetAddress())
+	require.EqualValues(t, 42, logSource.Calls[0].machine.GetAgentPort())
 }
