@@ -136,8 +136,16 @@ func fileServerMiddleware(next http.Handler, staticFilesDir string) http.Handler
 			}
 			resourcePath := path.Join(staticFilesDir, path.Clean(urlPath))
 			if _, err := os.Stat(resourcePath); os.IsNotExist(err) {
-				// If file does not exist then return content of index.html.
-				http.ServeFile(w, r, path.Join(staticFilesDir, "index.html"))
+				// The static-page-content subdirectory contains optional files that
+				// can hold html to be embedded in different components. It is not an
+				// error if these files do not exist. We return HTTP NoContent status
+				// to indicate that the requested file does not exist.
+				if strings.HasPrefix(urlPath, "/assets/static-page-content") {
+					w.WriteHeader(http.StatusNoContent)
+				} else {
+					// If file does not exist then return content of index.html.
+					http.ServeFile(w, r, path.Join(staticFilesDir, "index.html"))
+				}
 			} else {
 				// If file exists then serve it.
 				http.FileServer(http.Dir(staticFilesDir)).ServeHTTP(w, r)
@@ -330,15 +338,44 @@ func trimBaseURLMiddleware(next http.Handler, baseURL string) http.Handler {
 	})
 }
 
+// Middleware that limits request body size.
+// It is used to prevent DoS attacks by limiting the number of bytes received
+// in the incoming HTTP requests. Accepts a maximum body size in bytes.
+// The requests can have a body of any size, but if the server will try to
+// read more bytes than the maximum body size, it will return an HTTP 413
+// Entity Too Large status code.
+// If the maximum body size is less than or equal to zero, the middleware is
+// skipped.
+func bodySizeLimiterMiddleware(next http.Handler, maxBodySize int64) http.Handler {
+	if maxBodySize <= 0 {
+		// No limit, so we can skip the middleware.
+		return next
+	}
+
+	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		if r.Body == nil || r.Body == http.NoBody {
+			// No body.
+			next.ServeHTTP(w, r)
+			return
+		}
+
+		// Limit the body to the maximum value.
+		r.Body = http.MaxBytesReader(w, r.Body, maxBodySize)
+
+		next.ServeHTTP(w, r)
+	})
+}
+
 // Global middleware function provides a common place to setup middlewares for
 // the server. It is invoked before everything.
-func (r *RestAPI) GlobalMiddleware(handler http.Handler, staticFilesDir, baseURL string, eventCenter eventcenter.EventCenter) http.Handler {
+func (r *RestAPI) GlobalMiddleware(handler http.Handler, staticFilesDir, baseURL string, eventCenter eventcenter.EventCenter, maxBodySize int64) http.Handler {
 	// last handler is executed first for incoming request
 	handler = fileServerMiddleware(handler, staticFilesDir)
 	handler = agentInstallerMiddleware(handler, staticFilesDir)
 	handler = sseMiddleware(handler, eventCenter)
 	handler = metricsMiddleware(handler, r.MetricsCollector)
 	handler = trimBaseURLMiddleware(handler, baseURL)
+	handler = bodySizeLimiterMiddleware(handler, maxBodySize)
 	handler = loggingMiddleware(handler)
 	return handler
 }
