@@ -28,8 +28,10 @@ func convertSharedNetworkParametersToRestAPI(keaParameters *keaconfig.SharedNetw
 			CacheMaxAge:    keaParameters.CacheMaxAge,
 		},
 		KeaConfigClientClassParameters: models.KeaConfigClientClassParameters{
-			ClientClass:          storkutil.NullifyEmptyString(keaParameters.ClientClass),
-			RequireClientClasses: keaParameters.RequireClientClasses,
+			ClientClass:               storkutil.NullifyEmptyString(keaParameters.ClientClass),
+			ClientClasses:             keaParameters.ClientClasses,
+			EvaluateAdditionalClasses: keaParameters.EvaluateAdditionalClasses,
+			RequireClientClasses:      keaParameters.RequireClientClasses,
 		},
 		KeaConfigDdnsParameters: models.KeaConfigDdnsParameters{
 			DdnsGeneratedPrefix:        storkutil.NullifyEmptyString(keaParameters.DDNSGeneratedPrefix),
@@ -107,8 +109,8 @@ func (r *RestAPI) convertSharedNetworkToRestAPI(sn *dbmodel.SharedNetwork) *mode
 		Name:             sn.Name,
 		Universe:         int64(sn.Family),
 		Subnets:          subnets,
-		AddrUtilization:  float64(sn.AddrUtilization) / 10,
-		PdUtilization:    float64(sn.PdUtilization) / 10,
+		AddrUtilization:  float64(sn.AddrUtilization) * 100,
+		PdUtilization:    float64(sn.PdUtilization) * 100,
 		Stats:            sn.Stats,
 		StatsCollectedAt: convertToOptionalDatetime(sn.StatsCollectedAt),
 	}
@@ -189,8 +191,10 @@ func (r *RestAPI) convertSharedNetworkFromRestAPI(restSharedNetwork *models.Shar
 					CacheMaxAge:    keaParameters.CacheMaxAge,
 				},
 				ClientClassParameters: keaconfig.ClientClassParameters{
-					ClientClass:          storkutil.NullifyEmptyString(keaParameters.ClientClass),
-					RequireClientClasses: keaParameters.RequireClientClasses,
+					ClientClass:               storkutil.NullifyEmptyString(keaParameters.ClientClass),
+					ClientClasses:             keaParameters.ClientClasses,
+					EvaluateAdditionalClasses: keaParameters.EvaluateAdditionalClasses,
+					RequireClientClasses:      keaParameters.RequireClientClasses,
 				},
 				DDNSParameters: keaconfig.DDNSParameters{
 					DDNSGeneratedPrefix:        storkutil.NullifyEmptyString(keaParameters.DdnsGeneratedPrefix),
