@@ -148,6 +148,16 @@ import { BadgeModule } from 'primeng/badge'
 import { MachinesTableComponent } from './machines-table/machines-table.component'
 import { ZonesPageComponent } from './zones-page/zones-page.component'
 import { ByteCharacterComponent } from './byte-character/byte-character.component'
+import { ZoneViewerComponent } from './zone-viewer/zone-viewer.component'
+import { ZoneViewerFeederComponent } from './zone-viewer-feeder/zone-viewer-feeder.component'
+import { ConfigMigrationPageComponent } from './config-migration-page/config-migration-page.component'
+import { ConfigMigrationTableComponent } from './config-migration-table/config-migration-table.component'
+import { ConfigMigrationTabComponent } from './config-migration-tab/config-migration-tab.component'
+import { DurationPipe } from './pipes/duration.pipe'
+import { ManagedAccessDirective } from './managed-access.directive'
+import { NotFoundPageComponent } from './not-found-page/not-found-page.component'
+import { UtilizationBarComponent } from './utilization-bar/utilization-bar.component'
+import { PoolBarsComponent } from './pool-bars/pool-bars.component'
 
 /** Create the OpenAPI client configuration. */
 export function cfgFactory() {
@@ -246,6 +256,15 @@ export function cfgFactory() {
         MachinesTableComponent,
         ZonesPageComponent,
         ByteCharacterComponent,
+        ZoneViewerComponent,
+        ZoneViewerFeederComponent,
+        ConfigMigrationPageComponent,
+        ConfigMigrationTableComponent,
+        ConfigMigrationTabComponent,
+        DurationPipe,
+        NotFoundPageComponent,
+        UtilizationBarComponent,
+        PoolBarsComponent,
     ],
     bootstrap: [AppComponent],
     imports: [
@@ -299,6 +318,7 @@ export function cfgFactory() {
         TreeTableModule,
         BadgeModule,
         SkeletonModule,
+        ManagedAccessDirective,
     ],
     providers: [
         {
