@@ -1,6 +1,4 @@
 import {
-    AbstractControl,
-    AsyncValidator,
     AsyncValidatorFn,
     UntypedFormArray,
     UntypedFormBuilder,
@@ -17,12 +15,12 @@ describe('FormProcessor', () => {
     let formBuilder: UntypedFormBuilder = new UntypedFormBuilder()
 
     it('copies a complex form control with multiple nesting levels', () => {
-        let validator1: ValidatorFn = (control: AbstractControl): ValidationErrors | null => {
+        let validator1: ValidatorFn = (): ValidationErrors | null => {
             return null
         }
-        let validator2: AsyncValidatorFn = (
-            control: AbstractControl
-        ): Promise<ValidationErrors | null> | Observable<ValidationErrors | null> => {
+        let validator2: AsyncValidatorFn = ():
+            | Promise<ValidationErrors | null>
+            | Observable<ValidationErrors | null> => {
             return new Promise(null)
         }
         let formArray = formBuilder.array([
@@ -42,6 +40,8 @@ describe('FormProcessor', () => {
             }),
             formBuilder.control('aaa'),
         ])
+        formArray.get('0.foo').markAsTouched()
+
         let clonedArray = processor.cloneControl(formArray)
 
         expect(clonedArray).toBeTruthy()
@@ -55,6 +55,7 @@ describe('FormProcessor', () => {
         expect(clonedArray.at(0).get('foo').value).toBe('abc')
         expect(clonedArray.at(0).get('foo').hasValidator(validator1)).toBeTrue()
         expect(clonedArray.at(0).get('foo').hasAsyncValidator(validator2)).toBeTrue()
+        expect(clonedArray.at(0).get('foo').touched).toBeTrue()
 
         expect(clonedArray.at(0).get('bar')).toBeTruthy()
         expect(clonedArray.at(0).get('bar')).toBeInstanceOf(UntypedFormGroup)
