@@ -1,4 +1,4 @@
-import { Component, TemplateRef, ViewChild } from '@angular/core'
+import { Component, ViewChild } from '@angular/core'
 import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 import { By } from '@angular/platform-browser'
 import { PaginatorModule } from 'primeng/paginator'
@@ -198,8 +198,6 @@ describe('JsonTreeComponent', () => {
             expect(instance.recursionLevel).toBe(index)
         }
 
-        const lastStandardNode = level
-
         // Reach limit - last node
         level = level.query(By.css('.tree-level'))
         instance = level.componentInstance as JsonTreeComponent
