@@ -1,34 +1,16 @@
-import { Component, OnDestroy, OnInit, ViewChild } from '@angular/core'
-import { Router, ActivatedRoute, ParamMap } from '@angular/router'
-
-import { Table } from 'primeng/table'
+import { AfterViewInit, Component, ViewChild } from '@angular/core'
+import { Router, ActivatedRoute, EventType } from '@angular/router'
 
 import { DHCPService } from '../backend/api/api'
-import { extractKeyValsAndPrepareQueryParams, getErrorMessage } from '../utils'
-import {
-    getTotalAddresses,
-    getAssignedAddresses,
-    parseSubnetsStatisticValues,
-    parseSubnetStatisticValues,
-    extractUniqueSharedNetworkPools,
-    SharedNetworkWithUniquePools,
-} from '../subnets'
-import { Subscription, lastValueFrom } from 'rxjs'
-import { map } from 'rxjs/operators'
+import { getErrorMessage } from '../utils'
+import { parseSubnetStatisticValues, extractUniqueSharedNetworkPools, SharedNetworkWithUniquePools } from '../subnets'
+import { lastValueFrom, EMPTY } from 'rxjs'
+import { catchError, filter, map } from 'rxjs/operators'
 import { SharedNetwork } from '../backend'
 import { MenuItem, MessageService } from 'primeng/api'
 import { Tab, TabType } from '../tab'
 import { SharedNetworkFormState } from '../forms/shared-network-form'
-
-/**
- * Specifies the filter parameters for fetching shared networks that may be
- * specified in the URL query parameters.
- */
-interface QueryParamsFilter {
-    text: string
-    dhcpVersion: '4' | '6'
-    appId: string
-}
+import { SharedNetworksTableComponent } from '../shared-networks-table/shared-networks-table.component'
 
 /**
  * Component for presenting shared networks in a table.
@@ -38,26 +20,15 @@ interface QueryParamsFilter {
     templateUrl: './shared-networks-page.component.html',
     styleUrls: ['./shared-networks-page.component.sass'],
 })
-export class SharedNetworksPageComponent implements OnInit, OnDestroy {
+export class SharedNetworksPageComponent implements AfterViewInit {
     SharedNetworkTabType = TabType
 
-    private subscriptions = new Subscription()
     breadcrumbs = [{ label: 'DHCP' }, { label: 'Shared Networks' }]
 
-    @ViewChild('networksTable') networksTable: Table
-
-    // networks
-    networks: SharedNetworkWithUniquePools[] = []
-    totalNetworks = 0
-
-    // filters
-    filterText = ''
-    dhcpVersions: any[]
-    queryParams: QueryParamsFilter = {
-        text: null,
-        dhcpVersion: null,
-        appId: null,
-    }
+    /**
+     * Table with shared networks component.
+     */
+    @ViewChild('networksTableComponent') table: SharedNetworksTableComponent
 
     // Tab menu
 
@@ -112,225 +83,60 @@ export class SharedNetworksPageComponent implements OnInit, OnDestroy {
     ) {}
 
     /**
-     * A component lifecycle hook invoked when the component instance is destroyed.
+     * Component lifecycle hook called after Angular completed the initialization of the
+     * component's view.
      *
-     * It unsubscribes from all subscriptions.
+     * We subscribe to router events to act upon URL and/or queryParams changes.
+     * This is done at this step, because we have to be sure that all child components,
+     * especially PrimeNG table in SharedNetworksTableComponent, are initialized.
      */
-    ngOnDestroy(): void {
-        this.subscriptions.unsubscribe()
-    }
-
-    /**
-     * A component lifecycle hook invoked when the component is initialized.
-     */
-    ngOnInit() {
-        // prepare list of DHCP versions, this is used in networks filtering
-        this.dhcpVersions = [
-            { label: 'any', value: null },
-            { label: 'DHCPv4', value: '4' },
-            { label: 'DHCPv6', value: '6' },
-        ]
-
-        const ssParams = this.route.snapshot.queryParamMap
-        let text = ''
-        if (ssParams.get('text')) {
-            text += ' ' + ssParams.get('text')
-        }
-        if (ssParams.get('appId')) {
-            text += ' appId:' + ssParams.get('appId')
-        }
-        this.filterText = text.trim()
-
-        // subscribe to subsequent changes to query params
-        this.subscriptions.add(
-            this.route.queryParamMap.subscribe(
-                (params) => {
-                    this.updateOurQueryParams(params)
-                    let event = { first: 0, rows: 10 }
-                    if (this.networksTable) {
-                        // When filtering is applied, go by default to first page after filtering.
-                        this.networksTable.first = 0
-                        event = this.networksTable.createLazyLoadMetadata()
-                    }
-                    this.loadNetworks(event)
-                },
-                // ToDo: Silent error catching
-                (error) => {
-                    console.log(error)
-                }
-            )
-        )
-
-        // Subscribe to the shared network id changes, e.g. from /dhcp/shared-networks/all to
-        // /dhcp/shared-networks/1. These changes are triggered by switching between the
-        // tabs.
-        this.subscriptions.add(
-            this.route.paramMap.subscribe(
-                (params) => {
-                    // Get shared network id.
-                    const id = params.get('id')
-                    if (!id || id === 'all') {
-                        this.switchToTab(0)
-                        return
-                    }
-                    if (id === 'new') {
-                        this.openNewSharedNetworkTab()
-                        return
-                    }
-                    let numericId = parseInt(id, 10)
-                    if (Number.isNaN(numericId)) {
-                        numericId = 0
-                    }
-                    this.openTabBySharedNetworkId(numericId)
-                },
-                (error) => {
+    ngAfterViewInit(): void {
+        this.router.events
+            .pipe(
+                filter((event, idx) => idx === 0 || event.type === EventType.NavigationEnd),
+                catchError((err) => {
+                    const msg = getErrorMessage(err)
                     this.messageService.add({
                         severity: 'error',
-                        summary: 'Cannot process URL segment parameters',
-                        detail: getErrorMessage(error),
+                        summary: 'Cannot process the URL query',
+                        detail: msg,
+                        life: 10000,
                     })
-                }
+                    return EMPTY
+                })
             )
-        )
-    }
+            .subscribe(() => {
+                const paramMap = this.route.snapshot.paramMap
+                const queryParamMap = this.route.snapshot.queryParamMap
 
-    /**
-     * Update various component's query parameters from the URL
-     * query parameters.
-     *
-     * @param params query parameters.
-     */
-    updateOurQueryParams(params: ParamMap) {
-        if (['4', '6'].includes(params.get('dhcpVersion'))) {
-            this.queryParams.dhcpVersion = params.get('dhcpVersion') as '4' | '6'
-        }
-        this.queryParams.text = params.get('text') || null
-        this.queryParams.appId = params.get('appId') || null
-    }
+                // Apply to the changes of the shared network id, e.g. from /dhcp/shared-networks/all to
+                // /dhcp/shared-networks/1. Those changes are triggered by switching between the
+                // tabs.
 
-    /**
-     * Loads shared networks from the database into the component.
-     *
-     * @param event Event object containing index of the first row, maximum number
-     *              of rows to be returned, dhcp version and text for networks filtering.
-     */
-    loadNetworks(event) {
-        this.loading = true
-
-        const params = this.queryParams
-        lastValueFrom(
-            this.dhcpApi
-                .getSharedNetworks(
-                    event.first,
-                    event.rows,
-                    Number(params.appId) || null,
-                    Number(params.dhcpVersion) || null,
-                    params.text
-                )
-                .pipe(
-                    map((sharedNetworks) => {
-                        parseSubnetsStatisticValues(sharedNetworks.items)
-                        return sharedNetworks
-                    })
-                )
-        )
-            .then((data) => {
-                this.networks = data.items || []
-                this.totalNetworks = data.total ?? 0
-            })
-            .catch((error) => {
-                // ToDo: Silent error catching. We should display a message to the user.
-                console.log(error)
-            })
-            .finally(() => {
-                this.loading = false
-            })
-    }
-
-    /**
-     * Filters the list of shared networks by DHCP versions. Filtering is performed
-     * by the server.
-     */
-    filterByDhcpVersion() {
-        this.router.navigate(['/dhcp/shared-networks'], {
-            queryParams: { dhcpVersion: this.queryParams.dhcpVersion },
-            queryParamsHandling: 'merge',
-        })
-    }
-
-    /**
-     * Filters the list of shared networks by text. The text may contain key=val
-     * pairs allowing filtering by various keys. Filtering is performed by
-     * the server.
-     */
-    keyupFilterText(event) {
-        if (this.filterText.length >= 2 || event.key === 'Enter') {
-            const queryParams = extractKeyValsAndPrepareQueryParams<QueryParamsFilter>(this.filterText, ['appId'], null)
-
-            this.router.navigate(['/dhcp/shared-networks'], {
-                queryParams,
-                queryParamsHandling: 'merge',
-            })
-        }
-    }
-
-    /**
-     * Get the total number of addresses in the network.
-     */
-    getTotalAddresses(network: SharedNetwork) {
-        return getTotalAddresses(network)
-    }
-
-    /**
-     * Get the number of assigned addresses in the network.
-     */
-    getAssignedAddresses(network: SharedNetwork) {
-        return getAssignedAddresses(network)
-    }
-
-    /**
-     * Get the total number of delegated prefixes in the network.
-     */
-    getTotalDelegatedPrefixes(network: SharedNetwork) {
-        return network.stats?.['total-pds']
-    }
-
-    /**
-     * Get the number of delegated prefixes in the network.
-     */
-    getAssignedDelegatedPrefixes(network: SharedNetwork) {
-        return network.stats?.['assigned-pds']
-    }
-
-    /**
-     * Returns a list of applications maintaining a given shared network.
-     * The list doesn't contain duplicates.
-     *
-     * @param net Shared network
-     * @returns List of the applications (only ID and app name)
-     */
-    getApps(net: SharedNetwork) {
-        const apps = []
-        const appIds = {}
-
-        if (net.localSharedNetworks) {
-            net.localSharedNetworks.forEach((lsn) => {
-                if (!appIds.hasOwnProperty(lsn.appId)) {
-                    apps.push({ id: lsn.appId, name: lsn.appName })
-                    appIds[lsn.appId] = true
+                // Get shared network id.
+                const id = paramMap.get('id')
+                if (!id || id === 'all') {
+                    // Update the filter only if the target is shared network list.
+                    this.table?.updateFilterFromQueryParameters(queryParamMap)
+                    this.switchToTab(0)
+                    return
+                }
+                if (id === 'new') {
+                    this.openNewSharedNetworkTab()
+                    return
+                }
+                const numericId = parseInt(id, 10)
+                if (!Number.isNaN(numericId)) {
+                    // The path has a numeric id indicating that we should
+                    // open a tab with selected shared network information or switch
+                    // to this tab if it has been already opened.
+                    this.openTabBySharedNetworkId(numericId)
+                } else {
+                    // In case of failed Id parsing, open list tab.
+                    this.switchToTab(0)
+                    this.table?.loadDataWithoutFilter()
                 }
             })
-        }
-
-        return apps
-    }
-
-    /**
-     * Returns true if at least one of the shared networks contains at least
-     * one IPv6 subnet
-     */
-    get isAnyIPv6SubnetVisible(): boolean {
-        return !!this.networks?.some((n) => n.subnets.some((s) => s.subnet.includes(':')))
     }
 
     /**
@@ -548,9 +354,9 @@ export class SharedNetworksPageComponent implements OnInit, OnDestroy {
                 .toPromise()
                 .then((sharedNetwork) => {
                     this.openedTabs[index].tabSubject = sharedNetwork
-                    const existingIndex = this.networks.findIndex((n) => n.id === sharedNetwork.id)
+                    const existingIndex = this.table?.dataCollection?.findIndex((n) => n.id === sharedNetwork.id)
                     if (existingIndex >= 0) {
-                        this.networks[existingIndex] = sharedNetwork
+                        this.table.dataCollection[existingIndex] = sharedNetwork
                     }
                 })
                 .catch((error) => {
