@@ -25,6 +25,7 @@ import { StorkValidators } from '../validators'
 import { By } from '@angular/platform-browser'
 import { ArrayValueSetFormComponent } from '../array-value-set-form/array-value-set-form.component'
 import { HelpTipComponent } from '../help-tip/help-tip.component'
+import { MultiSelectModule } from 'primeng/multiselect'
 
 /**
  * Intrface to the form used in the unit tests.
@@ -35,6 +36,8 @@ interface SubnetForm {
     cacheThreshold?: SharedParameterFormGroup<number>
     ddnsGeneratedPrefix?: SharedParameterFormGroup<string>
     ddnsOverrideClientUpdate?: SharedParameterFormGroup<boolean>
+    dhcpDdnsEnableUpdates?: SharedParameterFormGroup<boolean>
+    hostReservationIdentifiers?: SharedParameterFormGroup<string[]>
     requireClientClasses?: SharedParameterFormGroup<string[]>
     relayAddresses?: SharedParameterFormGroup<string[]>
 }
@@ -58,6 +61,7 @@ describe('SharedParametersFormComponent', () => {
                 DropdownModule,
                 FormsModule,
                 InputNumberModule,
+                MultiSelectModule,
                 NoopAnimationsModule,
                 TableModule,
                 TagModule,
@@ -115,6 +119,21 @@ describe('SharedParametersFormComponent', () => {
                 },
                 [new FormControl('myhost', StorkValidators.fqdn), new FormControl('hishost', StorkValidators.fqdn)]
             ),
+            dhcpDdnsEnableUpdates: new SharedParameterFormGroup(
+                {
+                    type: 'boolean',
+                    required: true,
+                },
+                [new FormControl<boolean>(true), new FormControl<boolean>(true)]
+            ),
+            hostReservationIdentifiers: new SharedParameterFormGroup(
+                {
+                    type: 'string',
+                    isArray: true,
+                    values: ['hw-address', 'client-id', 'duid', 'circuit-id'],
+                },
+                [new FormControl(['hw-address']), new FormControl(['hw-address'])]
+            ),
             requireClientClasses: new SharedParameterFormGroup(
                 {
                     type: 'client-classes',
@@ -141,134 +160,164 @@ describe('SharedParametersFormComponent', () => {
             'cacheThreshold',
             'ddnsGeneratedPrefix',
             'ddnsOverrideClientUpdate',
+            'dhcpDdnsEnableUpdates',
+            'hostReservationIdentifiers',
             'relayAddresses',
             'requireClientClasses',
         ])
 
-        let allRows = fixture.debugElement.queryAll(By.css('tr'))
-        expect(allRows.length).toBe(8)
+        // Validate the section header.
+        let divs = fixture.debugElement.queryAll(By.css('.shared-parameter-wrapper.font-semibold > div'))
+        // First two divs are hidden for wider viewports, but visible for smaller viewports.
+        expect(divs.length).toBe(5)
+        // Check last three divs visible for larger viewports.
+        expect(divs[2].nativeElement.innerText).toBe('Parameter')
+        expect(divs[3].nativeElement.innerText).toBe('Value')
+        expect(divs[4].nativeElement.innerText).toBe('Unlock')
 
-        // Validate the table header.
-        let cells = allRows[0].queryAll(By.css('th'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Parameter')
-        expect(cells[1].nativeElement.innerText).toBe('Value')
-        expect(cells[2].nativeElement.innerText).toBe('Unlock')
+        let allWrapperDivs = fixture.debugElement.queryAll(By.css('.shared-parameter-wrapper:not(.font-semibold)'))
+        expect(allWrapperDivs.length).toBe(9)
 
         // Allocator.
-        cells = allRows[1].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Allocator')
-        let controls = cells[1].queryAll(By.css('p-dropdown'))
+        let labelDiv = allWrapperDivs[0].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('Allocator')
+        let controls = allWrapperDivs[0].queryAll(By.css('p-dropdown'))
         expect(controls.length).toBe(2)
-        let tags = cells[1].queryAll(By.css('p-tag'))
+        let tags = allWrapperDivs[0].queryAll(By.css('p-tag'))
         expect(tags.length).toBe(2)
         expect(tags[0].nativeElement.innerText).toBe('server 1')
         expect(tags[1].nativeElement.innerText).toBe('server 2')
-        let btns = cells[1].queryAll(By.css('[label=Clear]'))
+        let btns = allWrapperDivs[0].queryAll(By.css('[label=Clear]'))
         expect(btns.length).toBe(2)
         expect(btns[0].nativeElement.innerText).toBe('Clear')
         expect(btns[1].nativeElement.innerText).toBe('Clear')
-        let checkbox = cells[2].query(By.css('p-checkbox'))
+        let checkbox = allWrapperDivs[0].query(By.css('p-checkbox'))
         expect(checkbox).toBeTruthy()
 
         // Cache Max Age.
-        cells = allRows[2].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Cache Max Age')
-        controls = cells[1].queryAll(By.css('p-inputNumber'))
+        labelDiv = allWrapperDivs[1].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('Cache Max Age')
+        controls = allWrapperDivs[1].queryAll(By.css('p-inputNumber'))
         expect(controls.length).toBe(2)
-        tags = cells[1].queryAll(By.css('p-tag'))
+        tags = allWrapperDivs[1].queryAll(By.css('p-tag'))
         expect(tags.length).toBe(2)
         expect(tags[0].nativeElement.innerText).toBe('server 1')
         expect(tags[1].nativeElement.innerText).toBe('server 2')
-        btns = cells[1].queryAll(By.css('[label=Clear]'))
+        btns = allWrapperDivs[1].queryAll(By.css('[label=Clear]'))
         expect(btns.length).toBe(2)
         expect(btns[0].nativeElement.innerText).toBe('Clear')
         expect(btns[1].nativeElement.innerText).toBe('Clear')
-        checkbox = cells[2].query(By.css('p-checkbox'))
+        checkbox = allWrapperDivs[1].query(By.css('p-checkbox'))
         expect(checkbox).toBeTruthy()
 
         // Cache Threshold.
-        cells = allRows[3].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Cache Threshold')
-        controls = cells[1].queryAll(By.css('p-inputNumber'))
+        labelDiv = allWrapperDivs[2].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('Cache Threshold')
+        controls = allWrapperDivs[2].queryAll(By.css('p-inputNumber'))
         expect(controls.length).toBe(2)
-        tags = cells[1].queryAll(By.css('p-tag'))
+        tags = allWrapperDivs[2].queryAll(By.css('p-tag'))
         expect(tags.length).toBe(2)
         expect(tags[0].nativeElement.innerText).toBe('server 1')
         expect(tags[1].nativeElement.innerText).toBe('server 2')
-        btns = cells[1].queryAll(By.css('[label=Clear]'))
+        btns = allWrapperDivs[2].queryAll(By.css('[label=Clear]'))
         expect(btns.length).toBe(2)
         expect(btns[0].nativeElement.innerText).toBe('Clear')
         expect(btns[1].nativeElement.innerText).toBe('Clear')
-        checkbox = cells[2].query(By.css('p-checkbox'))
+        checkbox = allWrapperDivs[2].query(By.css('p-checkbox'))
         expect(checkbox).toBeTruthy()
 
         // DDNS Generated Prefix.
-        cells = allRows[4].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('DDNS Generated Prefix')
-        controls = cells[1].queryAll(By.css('input'))
+        labelDiv = allWrapperDivs[3].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('DDNS Generated Prefix')
+        controls = allWrapperDivs[3].queryAll(By.css('input.p-inputtext'))
         expect(controls.length).toBe(2)
-        tags = cells[1].queryAll(By.css('p-tag'))
+        tags = allWrapperDivs[3].queryAll(By.css('p-tag'))
         expect(tags.length).toBe(2)
         expect(tags[0].nativeElement.innerText).toBe('server 1')
         expect(tags[1].nativeElement.innerText).toBe('server 2')
-        btns = cells[1].queryAll(By.css('[label=Clear]'))
+        btns = allWrapperDivs[3].queryAll(By.css('[label=Clear]'))
         expect(btns.length).toBe(2)
         expect(btns[0].nativeElement.innerText).toBe('Clear')
         expect(btns[1].nativeElement.innerText).toBe('Clear')
-        checkbox = cells[2].query(By.css('p-checkbox'))
+        checkbox = allWrapperDivs[3].query(By.css('p-checkbox'))
         expect(checkbox).toBeTruthy()
 
         // DDNS Override Client Update.
-        cells = allRows[5].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('DDNS Override Client Update')
-        controls = cells[1].queryAll(By.css('p-triStateCheckbox'))
+        labelDiv = allWrapperDivs[4].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('DDNS Override Client Update')
+        controls = allWrapperDivs[4].queryAll(By.css('p-triStateCheckbox'))
         expect(controls.length).toBe(1)
-        tags = cells[1].queryAll(By.css('p-tag'))
+        tags = allWrapperDivs[4].queryAll(By.css('p-tag'))
         expect(tags.length).toBe(0)
-        btns = cells[1].queryAll(By.css('[label=Clear]'))
+        btns = allWrapperDivs[4].queryAll(By.css('[label=Clear]'))
         expect(btns.length).toBe(1)
         expect(btns[0].nativeElement.innerText).toBe('Clear')
-        checkbox = cells[2].query(By.css('p-checkbox'))
+        checkbox = allWrapperDivs[4].query(By.css('p-checkbox'))
+        expect(checkbox).toBeTruthy()
+
+        // DHCP DDNS Enable Updates.
+        labelDiv = allWrapperDivs[5].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('DHCP DDNS Enable Updates')
+        controls = allWrapperDivs[5].queryAll(By.css('p-checkbox'))
+        expect(controls.length).toBe(3)
+        tags = allWrapperDivs[5].queryAll(By.css('p-tag'))
+        expect(tags.length).toBe(0)
+        btns = allWrapperDivs[5].queryAll(By.css('[label=Clear]'))
+        expect(btns.length).toBe(1)
+        expect(btns[0].nativeElement.innerText).toBe('Clear')
+
+        // Host Reservation Identifiers.
+        labelDiv = allWrapperDivs[6].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('Host Reservation Identifiers')
+        controls = allWrapperDivs[6].queryAll(By.css('p-multiSelect'))
+        expect(controls.length).toBe(1)
+        tags = allWrapperDivs[6].queryAll(By.css('p-tag'))
+        expect(tags.length).toBe(0)
+        btns = allWrapperDivs[6].queryAll(By.css('[label=Clear]'))
+        expect(btns.length).toBe(1)
+        expect(btns[0].nativeElement.innerText).toBe('Clear')
+        checkbox = allWrapperDivs[6].query(By.css('p-checkbox'))
         expect(checkbox).toBeTruthy()
 
         // Relay
-        cells = allRows[6].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Relay Addresses')
-        controls = cells[1].queryAll(By.css('app-array-value-set-form'))
+        labelDiv = allWrapperDivs[7].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('Relay Addresses')
+        controls = allWrapperDivs[7].queryAll(By.css('app-array-value-set-form'))
         expect(controls.length).toBe(2)
-        tags = cells[1].queryAll(By.css('p-tag'))
+        tags = allWrapperDivs[7].queryAll(By.css('p-tag'))
         expect(tags.length).toBe(2)
         expect(tags[0].nativeElement.innerText).toBe('server 1')
         expect(tags[1].nativeElement.innerText).toBe('server 2')
-        btns = cells[1].queryAll(By.css('[label=Clear]'))
+        btns = allWrapperDivs[7].queryAll(By.css('[label=Clear]'))
         expect(btns.length).toBe(2)
         expect(btns[0].nativeElement.innerText).toBe('Clear')
         expect(btns[1].nativeElement.innerText).toBe('Clear')
-        checkbox = cells[2].query(By.css('p-checkbox'))
+        checkbox = allWrapperDivs[7].query(By.css('p-checkbox'))
         expect(checkbox).toBeTruthy()
 
         // Require Client Classes.
-        cells = allRows[7].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Require Client Classes')
-        controls = cells[1].queryAll(By.css('app-dhcp-client-class-set-form'))
+        labelDiv = allWrapperDivs[8].queryAll(By.css('div.font-semibold'))
+        expect(labelDiv.length).toBe(1)
+        expect(labelDiv[0].nativeElement.innerText).toBe('Require Client Classes')
+        controls = allWrapperDivs[8].queryAll(By.css('app-dhcp-client-class-set-form'))
         expect(controls.length).toBe(2)
-        tags = cells[1].queryAll(By.css('p-tag'))
+        tags = allWrapperDivs[8].queryAll(By.css('p-tag'))
         expect(tags.length).toBe(2)
         expect(tags[0].nativeElement.innerText).toBe('server 1')
         expect(tags[1].nativeElement.innerText).toBe('server 2')
-        btns = cells[1].queryAll(By.css('[label=Clear]'))
+        btns = allWrapperDivs[8].queryAll(By.css('[label=Clear]'))
         expect(btns.length).toBe(2)
         expect(btns[0].nativeElement.innerText).toBe('Clear')
         expect(btns[1].nativeElement.innerText).toBe('Clear')
-        checkbox = cells[2].query(By.css('p-checkbox'))
+        checkbox = allWrapperDivs[8].query(By.css('p-checkbox'))
         expect(checkbox).toBeTruthy()
     })
 
@@ -292,25 +341,23 @@ describe('SharedParametersFormComponent', () => {
         ]
         fixture.detectChanges()
 
-        let allRows = fixture.debugElement.queryAll(By.css('tr'))
-        expect(allRows.length).toBe(2)
-
-        // Validate the table header.
-        let cells = allRows[0].queryAll(By.css('th'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Parameter')
-        expect(cells[1].nativeElement.innerText).toBe('Value')
-        expect(cells[2].nativeElement.innerText).toBe('Unlock')
+        // Validate the section header.
+        let divs = fixture.debugElement.queryAll(By.css('.shared-parameter-wrapper.font-semibold > div'))
+        // First div is hidden for wider viewports, but visible for smaller viewports.
+        expect(divs.length).toBe(3)
+        // Check last two divs visible for larger viewports.
+        expect(divs[1].nativeElement.innerText).toBe('Parameter')
+        expect(divs[2].nativeElement.innerText).toBe('Value')
 
         // Require Client Classes.
-        cells = allRows[1].queryAll(By.css('td'))
-        expect(cells.length).toBe(3)
-        expect(cells[0].nativeElement.innerText).toBe('Require Client Classes')
-        const controls = cells[1].queryAll(By.css('app-dhcp-client-class-set-form'))
+        divs = fixture.debugElement.queryAll(By.css('.shared-parameter-wrapper:not(.font-semibold) > div'))
+        expect(divs.length).toBe(2)
+        expect(divs[0].childNodes[0].nativeNode.innerText).toBe('Require Client Classes')
+        const controls = divs[1].queryAll(By.css('app-dhcp-client-class-set-form'))
         expect(controls.length).toBe(1)
 
         // Click the List button to list the classes.
-        const btns = cells[1].queryAll(By.css('[label=List]'))
+        const btns = divs[1].queryAll(By.css('[label=List]'))
         expect(btns.length).toBe(1)
         expect(btns[0].nativeElement.innerText).toBe('List')
         btns[0].nativeElement.click()
