@@ -318,6 +318,20 @@ describe('utils', () => {
         expect(uncamelCase('dhcpValue')).toBe('DHCP Value')
         expect(uncamelCase('pdValue')).toBe('PD Value')
         expect(uncamelCase('ipPrefix')).toBe('IP Prefix')
+        expect(uncamelCase('naValue')).toBe('NA Value')
+        expect(uncamelCase('na')).toBe('NA')
+        expect(uncamelCase('ip')).toBe('IP')
+        expect(uncamelCase('pd')).toBe('PD')
+        expect(uncamelCase('innerPdValue')).toBe('Inner PD Value')
+        expect(uncamelCase('innerPds')).toBe('Inner PDs')
+        expect(uncamelCase('innerIpPrefix')).toBe('Inner IP Prefix')
+        expect(uncamelCase('innerIps')).toBe('Inner IPs')
+        expect(uncamelCase('innerNaValue')).toBe('Inner NA Value')
+        expect(uncamelCase('innerNas')).toBe('Inner NAs')
+        expect(uncamelCase('innerNascar')).toBe('Inner Nascar')
+        expect(uncamelCase('idValue')).toBe('ID Value')
+        expect(uncamelCase('innerIdValue')).toBe('Inner ID Value')
+        expect(uncamelCase('innerIds')).toBe('Inner IDs')
         expect(uncamelCase('anotherParameter')).toBe('Another Parameter')
         expect(uncamelCase('_withUnderscore')).toBe('With Underscore')
         expect(uncamelCase('  ')).toBe('  ')
